@@ -4,7 +4,7 @@ import os, os.path
 import errno
 import gettext 
 
-APP_DATA_DIR     = os.path.join('/home/thomas/oste/test', 'share') 
+APP_DATA_DIR     = os.path.join('/home/thomas/svn/test', 'share') 
 ICON_DIR         = os.path.join(APP_DATA_DIR, 'pixmaps')
 TEXTURE_DIR      = os.path.join(ICON_DIR, 'glchess')
 GLADE_DIR        = os.path.join(APP_DATA_DIR, 'glchess')
@@ -26,7 +26,7 @@ import gtk.glade
 gtk.glade.bindtextdomain(DOMAIN, LOCALEDIR)
 gtk.glade.textdomain(DOMAIN)
 
-VERSION   = "2.21.2"
+VERSION   = "2.21.3"
 APPNAME   = _("glChess")
 ICON_NAME = 'gnome-glchess'
 
