@@ -20,21 +20,29 @@
  */
 
 #include <config.h>
-#include <gnome.h>
-#include <gconf/gconf-client.h>
+
 #include <string.h>
+#include <stdlib.h>
+
+#include <glib/gi18n.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtk.h>
 
 #include <games-preimage.h>
 #include <games-gridframe.h>
 #include <games-stock.h>
 #include <games-scores.h>
 #include <games-scores-dialog.h>
- 
+#include <games-conf.h>
+
+#ifdef HAVE_GNOME
+#include <gnome.h>
+#endif
+
 #include "pieces.h"
 
 #define APPNAME "gnotski"
-#define APPNAME_LONG "Klotski"
+#define APPNAME_LONG N_("Klotski")
 
 #define MINWIDTH 250
 #define MINHEIGHT 250
@@ -45,7 +53,8 @@
 #define SPACE_PADDING 5
 #define SPACE_OFFSET 4
 
-GConfClient *conf_client;
+#define KEY_LEVEL "level"
+#define KEY_LEVEL_INFO_GROUP "level_info"
 
 GtkWidget *window;
 GtkWidget *statusbar;
@@ -151,8 +160,10 @@ void set_piece_id (char *, gint, gint, gint);
 gint move_piece (gint, gint, gint, gint, gint);
 void copymap (char *, char *);
 gint mapcmp (char *, char *);
+#ifdef HAVE_GNOME
 gint save_state (GnomeClient *, gint, GnomeRestartStyle, gint,
 		 GnomeInteractStyle, gint fast, gpointer);
+#endif /* HAVE_GNOME */              
 void new_move (void);
 void game_score (void);
 gint game_over (void);
@@ -445,7 +456,7 @@ const levelinfo level[] = {
    7, 9, 148,
    "###.###"
    "#a...b#"
-   "#cceff#" "#ddegg#" "#dijjg#" "#hijjk#" "#hh*kk#" "#l***l#" "#######"},
+   "#cceff#" "#ddegg#" "#dijjg#" "#hijjk#" "#hh*kk#" "#l***m#" "#######"},
 
   /* puzzle name */
   {N_("Climb 24 Pro"), 3,
@@ -539,60 +550,90 @@ static const GOptionEntry options[] = {
 int
 main (int argc, char **argv)
 {
-  GnomeClient *client;
-  GnomeProgram *program;
+  GOptionContext *context;
   GtkWidget *vbox;
   GtkWidget *menubar;
-  gint win_width, win_height, startup_level;
-  GOptionContext *context;
+  gint startup_level;
+#ifdef HAVE_GNOME
+  GnomeClient *client;
+  GnomeProgram *program;
+#else
+  gboolean retval;
+  GError *error = NULL;
+#endif
+
+#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
+  /* If we're going to use gnome-vfs, we need to init threads before
+   * calling any glib functions.
+   */
+  g_thread_init (NULL);
+#endif
 
   setgid_io_init ();
+
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  context = g_option_context_new ("");
+  context = g_option_context_new (NULL);
+#if GLIB_CHECK_VERSION (2, 12, 0)
+  g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
+#endif
+
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+
+#ifdef HAVE_GNOME
   program = gnome_program_init (APPNAME, VERSION,
 				LIBGNOMEUI_MODULE,
 				argc, argv,
 				GNOME_PARAM_GOPTION_CONTEXT, context,
 				GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 
-  highscores = games_scores_new (&scoredesc);
+  client = gnome_master_client ();
+
+  g_signal_connect (client, "save_yourself",
+                    G_CALLBACK (save_state), argv[0]);
+  g_signal_connect (client, "die",
+                    G_CALLBACK (quit_game_cb), argv[0]);
+
+#else
+  g_option_context_add_group (context, gtk_get_option_group (TRUE));
+
+  retval = g_option_context_parse (context, &argc, &argv, &error);
+  g_option_context_free (context);
+  if (!retval) {
+    g_print ("%s", error->message);
+    g_error_free (error);
+    exit (1);
+  }
+#endif /* HAVE_GNOME */
+
+  g_set_application_name (_(APPNAME_LONG));
+
+  games_conf_initialise (APPNAME);
 
   games_stock_init ();
+
   gtk_window_set_default_icon_name ("gnome-klotski");
-  client = gnome_master_client ();
-  g_object_ref (G_OBJECT (client));
-  gtk_object_sink (GTK_OBJECT (client));
-  g_signal_connect (G_OBJECT (client), "save_yourself",
-		    G_CALLBACK (save_state), argv[0]);
-  g_signal_connect (G_OBJECT (client), "die",
-		    G_CALLBACK (quit_game_cb), argv[0]);
+  
+  highscores = games_scores_new (&scoredesc);
 
-  conf_client = gconf_client_get_default ();
+  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  gtk_window_set_title (GTK_WINDOW (window), _(APPNAME_LONG));
 
-  window = gnome_app_new (APPNAME, N_(APPNAME_LONG));
+  gtk_window_set_default_size (GTK_WINDOW (window), MINWIDTH, MINHEIGHT);
+  games_conf_add_window (GTK_WINDOW (window), NULL);
 
-  win_width = gconf_client_get_int (conf_client, "/apps/gnotski/width", NULL);
-  win_height =
-    gconf_client_get_int (conf_client, "/apps/gnotski/height", NULL);
-  startup_level =
-    gconf_client_get_int (conf_client, "/apps/gnotski/level", NULL);
+  startup_level = games_conf_get_integer (NULL, KEY_LEVEL, NULL);
 
-  gtk_window_set_default_size (GTK_WINDOW (window), win_width, win_height);
-
-  g_signal_connect (G_OBJECT (window), "delete_event",
+  g_signal_connect (window, "delete_event",
 		    G_CALLBACK (quit_game_cb), NULL);
-  g_signal_connect (G_OBJECT (window), "configure_event",
-		    G_CALLBACK (window_resize_cb), NULL);
-  g_signal_connect (G_OBJECT (window), "window_state_event",
+  g_signal_connect (window, "window_state_event",
 		    G_CALLBACK (window_state_cb), NULL);
 
 
   vbox = gtk_vbox_new (FALSE, 0);
-  gnome_app_set_contents (GNOME_APP (window), vbox);
+  gtk_container_add (GTK_CONTAINER (window), vbox);
 
   load_image ();
   create_space ();
@@ -603,7 +644,7 @@ main (int argc, char **argv)
   gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), gameframe, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), gtk_hseparator_new (), FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (vbox), statusbar, FALSE, FALSE, GNOME_PAD);
+  gtk_box_pack_end (GTK_BOX (vbox), statusbar, FALSE, FALSE, 0);
 
   if (session_xpos >= 0 && session_ypos >= 0)
     gtk_window_move (GTK_WINDOW (window), session_xpos, session_ypos);
@@ -612,13 +653,13 @@ main (int argc, char **argv)
 
   new_game (startup_level);
 
-  set_fullscreen_actions (FALSE);
-
   gtk_main ();
 
-  gnome_accelerators_sync ();
+  games_conf_shutdown ();
 
+#ifdef HAVE_GNOME
   g_object_unref (program);
+#endif /* HAVE_GNOME */
 
   return 0;
 }
@@ -940,7 +981,7 @@ game_score ()
     
   /* Level is complete */
   key = get_level_key (current_level);
-  gconf_client_set_bool (conf_client, key, TRUE, NULL);
+  games_conf_set_boolean (KEY_LEVEL_INFO_GROUP, key, TRUE);
   g_free (key);
   gtk_image_set_from_stock (GTK_IMAGE(level_image[current_level]), GTK_STOCK_YES, GTK_ICON_SIZE_MENU);
 
@@ -965,7 +1006,7 @@ configure_pixmaps_idle (void)
     if (tiles_preimage) {
       tiles_pixbuf = games_preimage_render (tiles_preimage,
 					    tile_size * THEME_TILE_SEGMENTS,
-					    tile_size * 2, NULL);
+					    tile_size * 2);
     }
 
     if (tiles_pixbuf == NULL) {
@@ -1132,6 +1173,13 @@ create_menubar (void)
   gtk_action_group_add_actions (action_group, entries,
 				G_N_ELEMENTS (entries), window);
 
+  fullscreen_action =
+    gtk_action_group_get_action (action_group, "Fullscreen");
+  leave_fullscreen_action =
+    gtk_action_group_get_action (action_group, "LeaveFullscreen");
+
+  set_fullscreen_actions (FALSE);
+
   ui_manager = gtk_ui_manager_new ();
   gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
   gtk_ui_manager_add_ui_from_string (ui_manager, ui_description, -1, NULL);
@@ -1178,7 +1226,7 @@ get_level_key (gint level_number)
 	}
     }
 
-    return g_strdup_printf ("/apps/gnotski/level_info/%08X/solved", ~result);
+    return g_strdup_printf ("%08X/solved", ~result);
 }
 
 void
@@ -1189,7 +1237,7 @@ load_solved_state (void)
     
     for (i = 0; i < max_level; i++) {
 	key = get_level_key (i);
-	if (gconf_client_get_bool (conf_client, key, NULL))
+	if (games_conf_get_boolean (KEY_LEVEL_INFO_GROUP, key, NULL))
 	    gtk_image_set_from_stock (GTK_IMAGE(level_image[i]), GTK_STOCK_YES, GTK_ICON_SIZE_MENU);
 	g_free (key);
     }
@@ -1198,13 +1246,14 @@ load_solved_state (void)
 void
 load_image (void)
 {
-  char *fname;
+  char *path;
+  GError *error = NULL;
 
-  fname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
-				     "gnotski.svg", FALSE, NULL);
-  if (g_file_test (fname, G_FILE_TEST_EXISTS)) {
-    tiles_preimage = games_preimage_new_from_file (fname, NULL);
-  } else {
+  path = g_build_filename (PIXMAPDIR, "gnotski.svg", NULL);
+  tiles_preimage = games_preimage_new_from_file (path, &error);
+  g_free (path);
+
+  if (!tiles_preimage) {
     GtkWidget *dialog;
 
     dialog = gtk_message_dialog_new (NULL,
@@ -1213,11 +1262,11 @@ load_image (void)
 				     GTK_BUTTONS_OK,
 				     _
 				     ("Could not find the image:\n%s\n\nPlease check that Klotski is installed correctly."),
-				     fname);
+				     error->message);
+    g_error_free (error);
     gtk_dialog_run (GTK_DIALOG (dialog));
     exit (1);
   }
-  g_free (fname);
 }
 
 static void
@@ -1470,12 +1519,6 @@ update_menu_state (void)
   action_is_sensitive = current_level > 0;
   action = gtk_action_group_get_action (action_group, "PrevPuzzle");
   gtk_action_set_sensitive (action, action_is_sensitive);
-
-  fullscreen_action =
-    gtk_action_group_get_action (action_group, "Fullscreen");
-  leave_fullscreen_action =
-    gtk_action_group_get_action (action_group, "LeaveFullscreen");
-
 }
 
 void
@@ -1488,8 +1531,7 @@ new_game (gint requested_level)
 
   games_scores_set_category (highscores, scorecats[current_level].key);
 
-  gconf_client_set_int (conf_client, "/apps/gnotski/level",
-			current_level, NULL);
+  games_conf_set_integer (NULL, KEY_LEVEL, current_level);
 
   prepare_map (current_level);
   games_grid_frame_set (GAMES_GRID_FRAME (gameframe), width, height);
@@ -1504,13 +1546,7 @@ quit_game_cb (GtkAction * action)
   gtk_main_quit ();
 }
 
-gboolean
-window_resize_cb (GtkWidget * w, GdkEventConfigure * e, gpointer data)
-{
-  gconf_client_set_int (conf_client, "/apps/gnotski/width", e->width, NULL);
-  gconf_client_set_int (conf_client, "/apps/gnotski/height", e->height, NULL);
-  return FALSE;
-}
+#ifdef HAVE_GNOME
 
 gint
 save_state (GnomeClient * client, gint phase,
@@ -1539,6 +1575,8 @@ save_state (GnomeClient * client, gint phase,
   return TRUE;
 }
 
+#endif /* HAVE_GNOME */
+
 void
 level_cb (GtkAction * action, GtkRadioAction * current)
 {
@@ -1568,7 +1606,11 @@ prev_level_cb (GtkAction * action)
 void
 help_cb (GtkAction * action)
 {
+#ifdef HAVE_GNOME
   gnome_help_display ("gnotski.xml", NULL, NULL);
+#else
+#warning need to port help to gtk-only!
+#endif /* HAVE_GNOME */
 }
 
 void
@@ -1579,16 +1621,24 @@ about_cb (GtkAction * action)
   gchar *license = games_get_license (_(APPNAME_LONG));
 
   gtk_show_about_dialog (GTK_WINDOW (window),
-			 "name", _(APPNAME_LONG),
+#if GTK_CHECK_VERSION (2, 11, 0)
+                         "program-name", _(APPNAME_LONG),
+#else
+                         "name", _(APPNAME_LONG),
+#endif
 			 "version", VERSION,
-			 "comments", _("Sliding Block Puzzles"),
+			 "comments", _("Sliding Block Puzzles\n\n"
+			 "Klotski is a part of GNOME Games."),
 			 "copyright",
 			 "Copyright \xc2\xa9 1999-2007 Lars Rydlinge",
-			 "license", license, "authors", authors,
-			 "documenters", documenters, "translator_credits",
-			 _("translator-credits"), "logo-icon-name",
-			 "gnome-klotski", "website",
-			 "http://www.gnome.org/projects/gnome-games/",
-			 "wrap-license", TRUE, NULL);
+			 "license", license,
+                         "wrap-license", TRUE,
+                         "authors", authors,
+			 "documenters", documenters,
+                         "translator-credits", _("translator-credits"),
+                         "logo-icon-name", "gnome-klotski",
+                         "website", "http://www.gnome.org/projects/gnome-games",
+                         "website-label", _("GNOME Games web site"),
+                         NULL);
   g_free (license);
 }
